include("GCode.js");

// Machine Configuration for LinuxCNC Mill type machines in Inch

function Lcnc_Mill(documentInterface, newDocumentInterface) {
    GCode.call(this, documentInterface, newDocumentInterface);

    // set output unit:
    this.unit = RS.Inch;
}

Lcnc_Mill.prototype = new GCode();

// change file extension from nc to ngc
Lcnc_Mill.prototype.getFileExtensions = function() {
    // set output file extension:
    return ["ngc"];
};

// change default to inch
Lcnc_Mill.prototype.initGlobalOptionWidget = function(w) {
    switch (w.objectName) {
    case "ZSafety":
        w.addItems(["2", "1", "0.5"]);         // available options in combo box
        w.setEditText("0.5");                    // preselected default option
        break;
    case "ZClear":
        w.addItems(["0.25", "0.5", "1"]);
        w.setEditText("0.25");
        break;
    case "ZCutting":
        w.addItems(["-0.125", "-0.25", "-0.5"]);
        w.setEditText("-0.125");
        break;
    }
};

// change default to inch
Lcnc_Mill.prototype.initLayerOptionWidget = function(w) {
    switch (w.objectName) {
    case "ZCutting":
        w.addItems(["default", "-0.125", "-0.250", "-0.375"]);
        w.currentText = "default";
        break;
    }
};

// change G00 to G0
Lcnc_Mill.prototype.getRapidMoveCode = function() {
    return "G0";
};

// change G01 to G1
Lcnc_Mill.prototype.getLinearMoveCode = function() {
    return "G1";
};

// change G02 to G2
Lcnc_Mill.prototype.getCircularCWMoveCode = function() {
    return "G2";
};

// change G03 to G3
Lcnc_Mill.prototype.getCircularCCWMoveCode = function() {
    return "G3";
};

// add preamble
GCode.prototype.writeHeader = function() {
    this.writeLine("G20 G17 G40 G49 G54 G64 P0.005 G80 G90 G94");
    this.writeRapidZMove(this.getSafetyZLevel());
    this.toolPosition = GCode.ToolPosition.Clear;
};

// change M30 to M2
Lcnc_Mill.prototype.writeFooter = function() {
    this.writeToolUp();
    this.writeRapidZMove(this.getSafetyZLevel());
    this.toolPosition = GCode.ToolPosition.Clear;
    this.writeLine("M2");
};

// turn off line numbers
Lcnc_Mill.prototype.getLineNumberCode = function() {
    return "";
};
